@@ -4,7 +4,6 @@
 # confusion. so we should add a flag to indicate if the experiment was
 # successful or not
 
-import re
 import ast
 import uuid
 
@@ -12,13 +11,13 @@ import click
 import parso
 
 import nbformat
-from ploomber_engine.tracking.translator import translate_parameters
+from ploomber_engine._translator import translate_parameters
 from IPython.core.interactiveshell import InteractiveShell
 
 from ploomber_engine.ipython import PloomberClient, add_to_sys_path
 from ploomber_engine.tracking.io import _process_content_data
 from ploomber_engine._telemetry import telemetry
-
+from ploomber_engine._util import find_cell_with_parameters_comment
 
 try:
     import jupytext
@@ -162,18 +161,10 @@ def _parse_cli_parameters(parameters):
     return {k: _parse_param(v) for k, v in pairs}
 
 
-def _find_cell_with_comment(nb):
-    for idx, cell in enumerate(nb["cells"]):
-        if re.match(r"\s*#\s*PARAMETERS?\s*", cell["source"]) or re.match(
-            r"\s*#\s*parameters?\s*", cell["source"]
-        ):
-            return idx, cell
-
-    return None, None
-
-
 @telemetry.log_call("track-execution")
-def track_execution(filename, parameters, database="experiments.db", quiet=False):
+def track_execution(
+    filename, parameters=None, database="experiments.db", quiet=False
+):
     """
     Execute a script or notebook and write outputs to a SQLite database
     """
@@ -184,9 +175,9 @@ def track_execution(filename, parameters, database="experiments.db", quiet=False
         raise click.ClickException(
             "Missing sklearn-evaluation: pip install sklearn-evaluation"
         )
-
+    parameters = parameters or dict()
     nb = jupytext.read(filename)
-    idx, _ = _find_cell_with_comment(nb)
+    _, idx = find_cell_with_parameters_comment(nb)
 
     if idx is None:
         click.echo("Could not find block with the # parameters comment")
